@@ -9,8 +9,8 @@ __title__ = 'airflow-clickhouse-plugin'
 __description__ = \
     'airflow-clickhouse-plugin - ' \
     'Airflow plugin to execute ClickHouse commands and queries'
-__version__ = '0.5.1'
-__author__ = 'Viktor Taranenko'
-__author_email__ = 'viktor@samsungnext.com'
+__version__ = '0.5.3'
+__author__ = 'Anton Bryzgalov, Viktor Taranenko'
+__author_email__ = 'tony.bryzgaloff@gmail.com, viktor@samsungnext.com'
 __license__ = 'MIT License'
 __url__ = 'https://github.com/whisklabs/airflow-clickhouse-plugin'
